@@ -60,6 +60,7 @@ class quantum_lab():
         for files in fileList:
             if files == fileName:
                 filePath = f"/mnt/{self.namespace}/{self.volumeName}/{fileName}"
+
         if filePath == "":
             raise ValueError(f"[ERROR] File {fileName} not found.")
 
@@ -120,18 +121,29 @@ class quantum_lab():
         fileList = os.listdir(self.volumePath)
         for files in fileList:
             if files == fileName:
-                filePath = f"{self.volumePath}/{fileName}"
+                filePath = f"/mnt/{self.namespace}/{self.volumeName}/{fileName}"
 
         if filePath == "":
             raise ValueError(f"[ERROR] File {fileName} not found.")
 
+        print("[FilePath] ", filePath)
         url_path = f"{self.url}/qcc/notebook/job"
 
         headers = {
             "Content-Type": "application/json",
-            "email": self.userID,
+            "emailId": self.userID,
         }
 
+        body = json.dumps({
+            "resource": {
+                "id": self.resourceID,
+                "name": self.resourceName
+            },
+            "type": uploadType,
+            "filePath": filePath,
+            "shot": shot,
+        })
+
         body = json.dumps({
             "uploadType": uploadType,
             "shot": shot,
@@ -147,11 +159,10 @@ class quantum_lab():
         
         data = response.json()
         
-
         print("{:<6} {:<15}".format("ID", "Created Status"))
-        print("{:<6} {:<15}".format(data["id"], 'Success' if data["status"] else 'Fail'))
+        print("{:<6} {:<15}".format(data["id"], data["status"]))
         
-        return data["jobId"]
+        return data["id"]
 
     def getList(self, limit = 0):
         url_path = f"{self.url}/v1/jobs"
