@@ -27,14 +27,14 @@ def getResource():
 
     data = json.loads(response.content)
     print("{:<40} {:<15} {:<10} {:<10} {:<10}".format("id", "name", "type", "status", "qubits"))
-    for vals in data["resources"]:
+    for vals in data["content"]:
         print("{:<40} {:<15} {:<10} {:<10} {:<10}".format(vals["id"], vals["name"], vals["type"], vals["status"], vals["qubits"]))
 
     return response.text
 
 def getResourceName(resourceId):
     url = "http://job-management.qcc.svc.cluster.local:8080"
-    url_path = f"{url}/v1/resources/{resourceID}"
+    url_path = f"{url}/v1/resources/{resourceId}"
 
     response = requests.get(f"{url_path}") # , params=params)
     
